@@ -2,15 +2,19 @@ import os
 import csv
 import time
 import torch
+import logging
 from filelock import FileLock
 from dataclasses import dataclass
 from typing import List, Optional
-from ratsnlp.nlpbook.utils import logger
 from torch.utils.data.dataset import Dataset
 from transformers import PreTrainedTokenizer
 from ratsnlp.nlpbook.classification.arguments import ClassificationTrainArguments
 
 
+logger = logging.getLogger("ratsnlp")
+logger.setLevel(logging.INFO)
+
+
 @dataclass
 class ClassificationExample:
     text_a: str
