@@ -2,18 +2,22 @@ import os
 import time
 import json
 import torch
+import logging
 from tqdm import tqdm
 from functools import partial
 from filelock import FileLock
 from dataclasses import dataclass
 from typing import List, Optional
-from ratsnlp.nlpbook.utils import logger
 from multiprocessing import Pool, cpu_count
 from transformers import PreTrainedTokenizer
 from torch.utils.data.dataset import Dataset
 from ratsnlp.nlpbook.qa import QATrainArguments
 
 
+logger = logging.getLogger("ratsnlp")
+logger.setLevel(logging.INFO)
+
+
 @dataclass
 class QAExample:
     # 질문 : 임종석이 여의도 농민 폭력 시위를 주도한 혐의로 지명수배 된 날은?
